# ifndef yyCodeMovement
# define yyCodeMovement

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* CodeMovement_Exit) ARGS ((void));

extern tTree CodeMovement ARGS ((tTree t));

extern void BeginCodeMovement ARGS ((void));
extern void CloseCodeMovement ARGS ((void));

# endif
